#ifndef DEFINE_ISLIB_SIGNAL_BLOCKER_HPP

#define DEFINE_ISLIB_SIGNAL_BLOCKER_HPP

namespace islib
  {
    //
    // Definition of class
    //
    class signal_blocker
      {
      public:
        //
        // Definition of type
        //
        typedef signal_blocker this_type;

        //
        // Declaration of constructor
        //
        signal_blocker ();

        //
        // Declaration of destructor
        //
        ~signal_blocker () throw ();
      };
  }

#endif // DEFINE_ISLIB_SIGNAL_BLOCKER_HPP

//
// End of file
//
